@@ -57,7 +57,7 @@ void RedditSession::linksFetched()
     if (!reply)
         return;
 
-    qDebug() << "fetched";
+    //qDebug() << "fetched";
 
     QByteArray ba = reply->readAll();
     //qDebug() << "data " << ba;
@@ -72,7 +72,7 @@ void RedditSession::linksFetched()
         QString url = v.property("url").toString();
         QString title = v.property("title").toString();        
         QString tnail = v.property("thumbnail").toString();
-        qDebug() << v.toString() << title << " U " << url << " TN " << tnail;
+        //qDebug() << v.toString() << title << " U " << url << " TN " << tnail;
         RedditEntry e;
         e.desc = title;
         e.url = url;
@@ -95,7 +95,7 @@ void RedditSession::fetchComments(const QString &commentaddr)
     QString url = "http://www.reddit.com";
     url.append(commentaddr);
     url.append(".xml");
-    qDebug() << "fetch " << url;
+    //qDebug() << "fetch " << url;
     QNetworkRequest req(url);
     QNetworkReply* reply = m_net->get(req);
     connect(reply, SIGNAL(finished()), this, SLOT(commentsFetched()));
@@ -107,7 +107,7 @@ class CommentsParser : public QXmlDefaultHandler
 
     bool startElement(const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts)
     {
-        qDebug() << "start " << localName;
+        //qDebug() << "start " << localName;
         if (localName == "description") {
             m_indesc = true;
             m_current = "";
@@ -120,7 +120,7 @@ class CommentsParser : public QXmlDefaultHandler
     }
     bool endElement(const QString& namespaceURI, const QString& localName, const QString& qName)
     {
-        qDebug() << "end" << localName;
+        //qDebug() << "end" << localName;
         if (localName == "description") {
             m_comments.append(m_current);
         }
@@ -133,7 +133,7 @@ class CommentsParser : public QXmlDefaultHandler
         if (m_indesc) {
             m_current.append(ch);
         }
-        qDebug() << "ch " << ch;
+        //qDebug() << "ch " << ch;
         return true;
 
     }
