@@ -16,6 +16,7 @@ struct RedditEntry {
     QString url;
     QString desc;
     QString permalink;
+    QString thumbnail;
 };
 
 typedef QVector<RedditEntry> REList;
@@ -27,12 +28,16 @@ Q_OBJECT
 public:
     explicit RedditSession(QObject *parent = 0);
 
-    void start();
+    void start(const QString& url);
     void fetchComments(const QString& commentaddr);
 
     const QVector<RedditEntry>& getEntries();
     const QStringList& comments() { return m_comments; }
 
+    QStringList getCategories();
+
+    QNetworkAccessManager* m_net;
+
 signals:
     void linksAvailable();
     void commentsAvailable();
@@ -50,7 +55,6 @@ private:
     QVector<RedditEntry> m_ents;
     QStringList m_comments;
 
-    QNetworkAccessManager* m_net;
 
     QScriptEngine* m_eng;
 
